/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.disk.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.disk.domain.CourseAuditRecord;
import vip.xiaonuo.disk.domain.CourseInfo;
import vip.xiaonuo.disk.dto.courseInfo.CourseInfoAddParam;
import vip.xiaonuo.disk.dto.courseInfo.CourseInfoEditParam;
import vip.xiaonuo.disk.dto.courseInfo.CourseInfoIdParam;
import vip.xiaonuo.disk.dto.courseInfo.CourseInfoPageParam;
import vip.xiaonuo.disk.mapper.CourseInfoMapper;
import vip.xiaonuo.disk.service.CourseInfoService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 课程信息表Service接口实现类
 *
 * @author honorfire
 * @date  2025/06/20 15:00
 **/
@Service
public class CourseInfoServiceImpl extends ServiceImpl<CourseInfoMapper, CourseInfo> implements CourseInfoService {

    @Resource
    private CourseInfoMapper courseInfoMapper;

    @Override
    public Page<CourseInfo> page(CourseInfoPageParam courseInfoPageParam) {
        QueryWrapper<CourseInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(courseInfoPageParam.getSortField(), courseInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(courseInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, courseInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(courseInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(CourseInfo::getCourseId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(CourseInfoAddParam courseInfoAddParam) {
        CourseInfo courseInfo = BeanUtil.toBean(courseInfoAddParam, CourseInfo.class);
        this.save(courseInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public CourseInfo addOne(CourseInfo courseInfo) {
        this.save(courseInfo);
        return courseInfo;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(CourseInfoEditParam courseInfoEditParam) {
        CourseInfo courseInfo = this.queryEntity(courseInfoEditParam.getCourseId());
        BeanUtil.copyProperties(courseInfoEditParam, courseInfo);
        this.updateById(courseInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public CourseInfo editOne(CourseInfo courseInfo) {
        this.updateById(courseInfo);
        return courseInfo;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<CourseInfoIdParam> courseInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(courseInfoIdParamList, CourseInfoIdParam::getCourseId));
    }

    @Override
    public CourseInfo detail(CourseInfoIdParam courseInfoIdParam) {
        return this.queryEntity(courseInfoIdParam.getCourseId());
    }

    @Override
    public CourseInfo queryEntity(String id) {
        CourseInfo courseInfo = this.getById(id);
        if(ObjectUtil.isEmpty(courseInfo)) {
            throw new CommonException("课程信息表不存在，id值为：{}", id);
        }
        return courseInfo;
    }

    @Override
    public Page<Map<String,Object>> queryList(Map param)
    {
        return courseInfoMapper.queryList(param,CommonPageRequest.defaultPage());
    }

    /**
     *  课程信息-全量列表
     */
    @Override
    public List<CourseInfo> queryCourseInfoList(Map param)
    {
        QueryWrapper<CourseInfo> queryWrapper = new QueryWrapper<>();
        return this.list(queryWrapper);
    }


    @Override
    public Map<String,Object> queryInfo(Map param)
    {
        return courseInfoMapper.queryInfo(param);
    }



}
